import { Vec2, Vec3 } from 'wtc-math';
import { Camera, CameraOptions } from './Camera';
export interface DollyCameraOptions {
    element: HTMLElement;
    enabled: boolean;
    target: Vec3;
    ease: number;
    inertia: number;
    enableRotate: boolean;
    rotateSpeed: number;
    autoRotate: boolean;
    autoRotateSpeed: number;
    enableZoom: boolean;
    zoomSpeed: number;
    zoomStyle: string;
    enablePan: boolean;
    panSpeed: number;
    minPolarAngle: number;
    maxPolarAngle: number;
    minAzimuthAngle: number;
    maxAzimuthAngle: number;
    minDistance: number;
    maxDistance: number;
}
export declare class DollyCamera extends Camera {
    element: HTMLElement;
    enabled: boolean;
    target: Vec3;
    zoomStyle: string;
    minDistance: number;
    maxDistance: number;
    enableRotate: boolean;
    autoRotate: boolean;
    enableZoom: boolean;
    enablePan: boolean;
    ease: number;
    inertia: number;
    rotateSpeed: number;
    autoRotateSpeed: number;
    zoomSpeed: number;
    panSpeed: number;
    minPolarAngle: number;
    maxPolarAngle: number;
    minAzimuthAngle: number;
    maxAzimuthAngle: number;
    sphericalDelta: Vec3;
    sphericalTarget: Vec3;
    spherical: Vec3;
    panDelta: Vec3;
    offset: Vec3;
    rotateStart: Vec2;
    panStart: Vec2;
    dollyStart: Vec2;
    state: number;
    mouseButtons: {
        ORBIT: number;
        ZOOM: number;
        PAN: number;
    };
    static STATE_NONE: number;
    static STATE_ROTATE: number;
    static STATE_DOLLY: number;
    static STATE_PAN: number;
    static STATE_DOLLY_PAN: number;
    constructor({ element, enabled, target, ease, inertia, enableRotate, rotateSpeed, autoRotate, autoRotateSpeed, enableZoom, zoomSpeed, zoomStyle, enablePan, panSpeed, minPolarAngle, maxPolarAngle, minAzimuthAngle, maxAzimuthAngle, minDistance, maxDistance }: Partial<DollyCameraOptions> | undefined, cameraOptions: CameraOptions);
    setPosition(x: number, y: number, z: number): void;
    update(): void;
    forcePosition(): void;
    getZoomScale(): number;
    panLeft(distance: number, m: number[]): void;
    panUp(distance: number, m: number[]): void;
    pan(deltaX: number, deltaY: number): void;
    dolly(dollyScale: number): void;
    handleAutoRotate(): void;
    handleMoveRotate(x: number, y: number): void;
    handleMouseMoveDolly(e: MouseEvent): void;
    handleMovePan(x: number, y: number): void;
    handleTouchStartDollyPan(e: TouchEvent): void;
    handleTouchMoveDollyPan(e: TouchEvent): void;
    onMouseDown(e: MouseEvent): void;
    onMouseMove(e: MouseEvent): void;
    onMouseUp(): void;
    onMouseWheel(e: WheelEvent): void;
    onTouchStart(e: TouchEvent): void;
    onTouchMove(e: TouchEvent): void;
    onTouchEnd(): void;
    onContextMenu(e: Event): void;
    addHandlers(): void;
    removeHandlers(): void;
}
