import { Vec2 } from 'wtc-math';
import type { WTCGLRenderingContext, WTCGLUniformArray } from '../../types';
import { Renderer } from '../../core/Renderer';
import { Program } from '../../core/Program';
import { Mesh } from '../../core/Mesh';
import { Uniform } from '../../core/Uniform';
import { PointCloud } from '../../geometry/PointCloud';
import { Camera } from '../../core/Camera';
import { Framebuffer } from '../../ext/Framebuffer';
export interface ParticleSimulationOptions {
    vertex: string;
    fragment: string;
    dimensions: Vec2;
    container: HTMLElement;
    autoResize: boolean;
    uniforms: WTCGLUniformArray;
    onBeforeRender: (delta: number) => void;
    onAfterRender: (delta: number) => void;
    textureSize: number;
    simDimensions: number;
    createGeometry: () => void;
    rendererProps: object;
}
export declare class ParticleSimulation {
    #private;
    uniforms: WTCGLUniformArray & {
        u_time: Uniform;
        u_resolution: Uniform;
    };
    dimensions: Vec2;
    autoResize: boolean;
    onBeforeRender: (delta: number) => void;
    onAfterRender: (delta: number) => void;
    u_time: Uniform;
    u_resolution: Uniform;
    gl: WTCGLRenderingContext;
    renderer: Renderer;
    program: Program;
    mesh: Mesh;
    textureSize: number;
    particles: number;
    textureArraySize: number;
    simDimensions: number;
    references: Float32Array;
    cloud: PointCloud;
    lastTime: number;
    constructor({ vertex, fragment, dimensions, container, autoResize, uniforms, onBeforeRender, onAfterRender, textureSize, simDimensions, createGeometry, rendererProps }?: Partial<ParticleSimulationOptions>);
    createGeometry(): void;
    render(t: number): void;
    resize(): void;
    set post(p: Framebuffer);
    get post(): Framebuffer;
    set playing(v: boolean);
    get playing(): boolean;
    set camera(v: Camera | undefined);
    get camera(): Camera | undefined;
    set update(v: boolean);
    get update(): boolean;
    set sort(v: boolean);
    get sort(): boolean;
    set frustumCull(v: boolean);
    get frustumCull(): boolean;
    set clear(v: boolean | undefined);
    get clear(): boolean | undefined;
    set viewport(v: [Vec2, Vec2] | undefined);
    get viewport(): [Vec2, Vec2] | undefined;
}
